<?php 
use App\Models\User;
use Illuminate\Support\Facades\Cache;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use Twilio\Rest\Client;

if (!function_exists('getUserName')) {
    function getUserName($userId)
    {
        return User::where('id', $userId)->value('name');
    }
}

if (!function_exists('get_title')) {
    function get_title($table, $condition, $value)
    {
        $row = DB::table($table)->where($condition)->first();
        return $row ? $row->$value : '';
    }
}

if (!function_exists('getToken')) {
    function getToken()
    {
        $cacheTTL = 30; // Token validity in minutes
        $storedToken = DB::table('api_tokens')->latest('updated_at')->first();
    
        // Check if a token exists and is still valid
        if ($storedToken && (now()->timestamp - strtotime($storedToken->updated_at) < $cacheTTL * 60)) {
            return ['access_token' => $storedToken->token];
        }
    
        // Token has expired or doesn't exist, generate a new one
        $ch = curl_init();
        $url = 'https://us-api.experian.com/oauth2/v1/token';
        curl_setopt($ch, CURLOPT_URL, $url);
    
        $headers = [
            'Accept: application/json',
            'Content-Type: application/json',
            'client_id: jwuo2HpQKy5Bgc3SYv3ekG6abNlHpqB8',
            'client_secret: TGxCyr2AAiQf9JYd'
        ];
        curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
    
        $jsonData = [
            'username' => '6000096@accuselect.com',
            'password' => '0HUugA80G?>_'
        ];
        curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($jsonData));
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
    
        $response = curl_exec($ch);
        if (curl_errno($ch)) {
            $error = curl_error($ch);
            curl_close($ch);
            Log::error('Token generation error: ' . $error);
            return ['error' => 'Failed to generate token: ' . $error];
        }
        curl_close($ch);
    
        $responseArray = json_decode($response, true);
        if (json_last_error() !== JSON_ERROR_NONE) {
            Log::error('JSON decode error: ' . json_last_error_msg());
            return ['error' => 'Failed to parse token response'];
        }
    
        if (!isset($responseArray['access_token'])) {
            Log::error('No access token found in response');
            return ['error' => 'No access token found in response'];
        }
    
        if ($storedToken) {
            DB::table('api_tokens')->where('id', $storedToken->id)->update([
                'token' => $responseArray['access_token'],
                'updated_at' => now(),
            ]);
        } else {
            DB::table('api_tokens')->insert([
                'token' => $responseArray['access_token'],
                'created_at' => now(),
                'updated_at' => now(),
            ]);
        }
    
        return $responseArray;
    }
}

if (!function_exists('getVehicleDetails')) {
    function getVehicleDetails($tokenKey, $licensePlate, $state)
    {
        $ch = curl_init();
        $url = 'https://us-api.experian.com/automotive/accuselect/v1/recallplus/plate/' . urlencode($licensePlate) . '/state/' . urlencode($state);
        curl_setopt($ch, CURLOPT_URL, $url);

        $headers = [
            'Authorization: Bearer ' . $tokenKey,
            'Content-Type: application/json',
            'Accept: application/json'
        ];
        curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);

        $response = curl_exec($ch);

        if (curl_errno($ch)) {
            curl_close($ch);
            return ['error' => curl_error($ch)];
        }
        curl_close($ch);

        return json_decode($response, true); 
    }
}

if (!function_exists('sendOtp')) {
    function sendOtp($to, $otp, $msgbody)
    {
        return 'SM55d149b41dbdceaa815c6362dce97345';

        try {
            $accountSid = env('TWILIO_ACCOUNT_SID');
            $authToken = env('TWILIO_AUTH_TOKEN');
            $twilioNumber = env('TWILIO_PHONE_NUMBER');       
        
            $client = new Client($accountSid, $authToken);
            $message = $client->messages->create(
                $to,
                [
                    'from' => $twilioNumber,
                    'body' => "$msgbody $otp"
                ]
            );
            return $message->sid;
        } catch (\Exception $e) {
            return $e->getMessage();
        }
    }
}

if (!function_exists('sendOtpToMultiple')) {
    function sendOtpToMultiple($phoneNumbers, $otp, $msgbody)
    {
        $responses = [];
        foreach ($phoneNumbers as $phone) {
            $response = sendOtp($phone, $otp, $msgbody);
            $responses[$phone] = $response;
        }
        return $responses;
    }
}

if (!function_exists('countrySelect')) {
    function countrySelect($selectedCountryCode = null)
    {
        $countries = \App\Models\Country::all(); // Ensure the Country model is correctly imported
        
        $selectTag = "<select name='countryCode' id='countryCode' class='form-control' required=''>";
        foreach ($countries as $country) {
            $isSelected = ($selectedCountryCode == $country->phonecode) ? 'selected' : '';
            $selectTag .= "<option value='+{$country->phonecode}' {$isSelected}>+{$country->phonecode} ({$country->nicename})</option>";
        }
        $selectTag .= "</select>";

        return $selectTag;
    }
}

define("ENCRYPTION_KEY", "!@#$%^&*");

function encryptID($string, $key) 
{
    $encrypted = openssl_encrypt($string, 'AES-128-ECB', $key);
    $base64 = base64_encode($encrypted);
    return rtrim(strtr($base64, '+/', '-_'), '=');
}

function decryptID($encrypted, $key) 
{
    $base64 = str_pad(strtr($encrypted, '-_', '+/'), strlen($encrypted) % 4, '=', STR_PAD_RIGHT);
    $encrypted = base64_decode($base64);
    return openssl_decrypt($encrypted, 'AES-128-ECB', $key);
}

if (!function_exists('compressImage')) {
    function compressImage($source, $destination, $quality)
    {
        $imgInfo = getimagesize($source);
        $mime = $imgInfo['mime'];
    
        switch ($mime) {
            case 'image/jpeg':
                $image = imagecreatefromjpeg($source);
                break;
            case 'image/png':
                $image = imagecreatefrompng($source);
                break;
            case 'image/gif':
                $image = imagecreatefromgif($source);
                break;
            default:
                $image = imagecreatefromjpeg($source);
        }
    
        imagejpeg($image, $destination, $quality);   
        return $destination;
    }
}