<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Http;
use App\Models\State;
use App\Models\Customer; 
use App\Models\Vehicles; 
use Illuminate\Support\Facades\Session;
use App\Models\User; // Assuming you have a User model
use Carbon\Carbon; // Make sure you have Carbon imported for date formatting
use Illuminate\Support\Facades\Crypt;
use Intervention\Image\Laravel\Facades\Image;
// use Intervention\Image\Facades\Image;
// use Spatie\Image\Image as spatieImage;
use Illuminate\Support\Facades\Log;


class Home extends Controller
{

    public function index(Request $request)
    {
        $dealerId = $request->query('dealerId');
        $sourceTypeValue = $request->query('sourceType');
    
        $dealer = User::where(['url'=>$dealerId,'status'=>'1','isDeleted'=>'1'])->first();
    
        if (!$dealerId || !$dealer) {
            abort(404, 'Dealer not found');
        }
        
      $urldealerId =  $dealer->id;
        $sourceType = 'Other';
        if ($sourceTypeValue) {
            switch ($sourceTypeValue) {
                case 'qr':
                    $sourceType = 'qr';
                    break;

                case 'web':
                    $sourceType = 'web';                   
                     break;
    
                case 'text':
                    $sourceType = 'text'; 
                    break;
    
                default:
                $sourceType = 'Other';
                   
                    break;
            }
        }
        $request->session()->put('urlDealerId', $urldealerId);
        $request->session()->put('urlSourceType', $sourceType);

        $states = State::all();
        return view('home.index', compact('states'));
    }


    // public function index(Request $request)
    // {
    //     $states = State::all();
    //     return view('home.index', compact('states'));
    // }
    
    public function vehicleDetails()
    {
        return view('home.vehicleDetails');
    }

    public function vehicleDetailNo()
    {
        return view('home.serviceNoFile.vehicleDetails');
    }

    public function findVehicle(Request $request)
    {
        $request->validate([
            'carService' => 'required',
            'licensePlate' => 'required',
            'state' => 'required',
        ]);

        $licensePlate = $request->licensePlate;
        $state = $request->state;
        $tokenResponse = getToken();

        if (isset($tokenResponse['error'])) {
            return back()->withErrors(['error' => 'The license plate and state, or VIN, is not recognized. Please try again.']);
        }
        $tokenKey = $tokenResponse['access_token'] ?? null;

        if (!$tokenKey) {
            return back()->withErrors(['error' => 'The license plate and state, or VIN, is not recognized. Please try again.']);
        }

        $where = [
            ['date', '>=', date('Y-m-d', strtotime('-7 days'))],
            ['date', '<=', date('Y-m-d')],
            ['licensePlate', '=', $licensePlate],
            ['state', '=', $state]
        ];

        $vehicleInfo = Vehicles::where($where)->first();

        if ($vehicleInfo) {
            // Structure the data as the API response
            $vehicleDetailsTable = [
                'recallPlus' => [
                    'vehicleCount' => 1,
                    'vehicle' => [
                        [
                            'vin' => $vehicleInfo->vin,
                            'vinspec' => [
                                'year' => $vehicleInfo->year,
                                'make' => $vehicleInfo->make,
                                'model' => $vehicleInfo->model,
                                'class' => $vehicleInfo->class,
                                'country' => $vehicleInfo->country,
                                'body' => $vehicleInfo->body,
                                'engine' => $vehicleInfo->engine,
                            ],
                            'serviceBulletin' => 'N',
                            'recall' => 'N',
                            'resultCode' => 0,
                            'resultMessage' => 'No error.',
                        ]
                    ]
                ]
            ];

            $vehicleDetailsResponse = response()->json($vehicleDetailsTable, 200);

        } else {
            $vehicleDetailsResponse = getVehicleDetails($tokenKey, $licensePlate, $state);

            if (isset($vehicleDetailsResponse['errors'])) {
                return back()->withErrors(['error' => 'The license plate and state, or VIN, is not recognized. Please try again.']);
            }
            
            $vehicleResponse = $vehicleDetailsResponse['recallPlus']['vehicle'][0];
            $vinSpec = $vehicleResponse['vinspec'];
            $vehicleExists = Vehicles::select('id')->where($where)->first();

            if ($vehicleExists) {
                $vehicleUpdate = Vehicles::find($vehicleExists->id);
                $vehicleUpdate->update([
                    'date' => date('Y-m-d'),
                    'licensePlate' => $licensePlate,
                    'state' => $state,
                    'vin' => $vehicleResponse['vin'],
                    'year' => $vinSpec['year'],
                    'make' => $vinSpec['make'],
                    'model' => $vinSpec['model'],
                    'class' => $vinSpec['class'],
                    'country' => $vinSpec['country'],
                    'body' => $vinSpec['body'],
                    'engine' => $vinSpec['engine'],
                    'created' => date('d-m-Y h:i:s A')
                ]);
            } else {
                Vehicles::create([
                    'date' => date('Y-m-d'),
                    'licensePlate' => $licensePlate,
                    'state' => $state,
                    'vin' => $vehicleResponse['vin'],
                    'year' => $vinSpec['year'],
                    'make' => $vinSpec['make'],
                    'model' => $vinSpec['model'],
                    'class' => $vinSpec['class'],
                    'country' => $vinSpec['country'],
                    'body' => $vinSpec['body'],
                    'engine' => $vinSpec['engine'],
                    'created' => date('d-m-Y h:i:s A')
                ]);
            }
        }
        // return $vehicleDetailsResponse;
        $request->session()->put('vehicleDetailsResponse', $vehicleDetailsResponse);
        $request->session()->put('licensePlate',  $licensePlate);
        $request->session()->put('state',  $state);
        $request->session()->put('carService', $request->carService);

        if ($request->carService == 'Yes') {
            return redirect('/vehicleDetail');
        } else {
            return redirect('/vehicleServiceNo');
        }
    }

    public function verifyUserOTP()
    {
        return view('home.verifyOTP');
    }
    public function verifyServiceNo()
    {
        return view('home.serviceNoFile.verifyOTPServiceNo');
    }

    public function verifyOTP(Request $request)
    {
        $request->validate([
            'carService' => 'required',
            'carColor' => 'required',
            'mobile' => 'required|numeric',
        ]);

        $phone = $request->countryCode . $request->mobile;
        $otp = rand(100000, 999999); 
        $msgbody= 'Dear customer verify your mobile to continue, and your OTP is: ';
        $response = sendOtp($phone, $otp, $msgbody);

        if (is_string($response) && strpos($response, 'SM') === 0) {

            $request->session()->put('otp', $otp);
            $request->session()->put('otp', '123456');

            $request->session()->put('carColor', $request->carColor);
            $request->session()->put('serviceAdvisor', $request->serviceAdvisor);
            $request->session()->put('mobile', $request->mobile);
            $request->session()->put('countryCode', $request->countryCode);
            $request->session()->put('OTPsended', 'true');
            $request->session()->put('carService', $request->carService);

            $Customer = Customer::create([
                'date' => date('Y-m-d'),
                'custOTPstatus' => 'generated',
                'customerMobile' => $phone ?? '',
                'serviceType'=>$request->carService ?? '',
                'AdvisorCheck' => $request->AdvisorCheck ?? '',
                'licensePlate'=>$request->licensePlate ?? '',
                'state'=>$request->state ?? '',
                'vin'=>$request->vin ?? '',
                'year'=> $request->year ?? '',
                'make'=>$request->make ?? '',
                'model'=>$request->model ?? '',
               'color'=> $request->carColor ?? '',
               'mileage' => $request->mileage ?? '',
               'serviceAdvisorName' =>$request->serviceAdvisor,
               'dealerId'=> session()->get('urlDealerId'),
               'sourceType' => session()->get('urlSourceType'),

            ]);
            $request->session()->put('generatedCustomerId',  $Customer->customerId);

            if ($request->carService == 'Yes') {
                return redirect('/verifyOTP');
            } else {
                $request->session()->put('AdvisorCheck', $request->AdvisorCheck ?? '');
                return redirect('/verifyServiceNo');
            }
        } else {
            $errorMessage = is_string($response) ? $response : 'An unexpected error occurred while sending OTP. Please try again.';
            return back()->with('otp_error', 'Failed to send OTP: Please try again or enter your phone number with country code and check network connection.')->withInput();
        }
    }
    
    public function verifyOtpAjax(Request $request)
    {
        // Validate the request
        $request->validate([
            'mobile' => 'required|numeric',
            'otp' => 'required|numeric|digits:6',
        ]);

        $mobile = $request->input('mobile');
        $otp = $request->input('otp');

        // Verify OTP
        if (session()->get('otp') == $otp) {
            // OTP matched
            $otp = ''; // Reset OTP after successful verification
            $msgbody = 'Thank you for requesting a vehicle appraisal. Our used car manager will be very thorough reviewing your car in order to offer you the best price. Appraisals typically take 20-30 minutes. You will receive a text message with your no-obligation cash offer and a reminder that your offer is good for 7 days. Thank You!';

            // Send confirmation message to the customer
            $response = sendOtp($mobile, $otp, $msgbody);

            if (is_string($response) && strpos($response, 'SM') === 0) {

                $managers = User::where([
                    'roleType' => 'Manager',
                    'status' => '1',
                    'isDeleted' => '1',
                    'dealerId' => session()->get('urlDealerId')
                ])->get(['mobile', 'countryCode']);
                
                $phoneNumbers = $managers->map(function ($manager) {
                    return $manager->countryCode . $manager->mobile;
                })->toArray();
                
                // return $phoneNumbers;
                $otp = ''; // Generate a random 6-digit OTP
                $msgbody = "Customer appraisal request received."; 

                // Send OTP to managers
                $responses = sendOtpToMultiple($phoneNumbers, $otp, $msgbody);
                // Check if any manager received the message
                session()->forget('otp');

                $generatedCustomerId = $request->session()->get('generatedCustomerId');

                $formattedTimestamp = Carbon::now()->format('l / d-m-Y / H:i:s A'); // Example: "Monday / 06/08/2024 / 12:34:56"

                $customer = Customer::where('customerId', $generatedCustomerId)->first();

                $customer->requestTimestampCust = $formattedTimestamp;
                $customer->save();


                foreach ($responses as $phone => $response) {
                    if (is_string($response) && strpos($response, 'SM') === 0) {
                        // At least one message sent successfully
                        return response()->json(['success' => true]);

                    }
                }

                // return response()->json(['success' => true]);

            } else {
                return response()->json(['success' =>false, 'error' =>'Please try again or check network connection.']);
            }
        } else {
            return response()->json(['success' =>'wrong OTP', 'error' => 'Invalid OTP.']);
        }
    }

    public function verifyServiceNoAjax(Request $request)
    {
         // Validate the request
         $request->validate([
            'mobile' => 'required',
            'otp' => 'required|numeric|digits:6',
        ]);

        $mobile = $request->input('mobile');
        $otp = $request->input('otp');

        // Verify OTP
        if (session()->get('otp') == $otp) {
            // OTP matched
            $otp = ''; // Reset OTP after successful verification
            $msgbody = 'Thank you for requesting a vehicle appraisal. Our used car manager will be very thorough reviewing your car in order to offer you the best price. Appraisals typically take 20-30 minutes. You will receive a text message with your no-obligation cash offer and a reminder that your offer is good for 7 days. Thank You!';

            // Send confirmation message to the customer
            $response = sendOtp($mobile, $otp, $msgbody);

            if (is_string($response) && strpos($response, 'SM') === 0) {

                $managers = User::where([
                    'roleType' => 'Manager',
                    'status' => '1',
                    'isDeleted' => '1',
                    'dealerId' => session()->get('urlDealerId')
                ])->get(['mobile', 'countryCode']);
                
                $phoneNumbers = $managers->map(function ($manager) {
                    return $manager->countryCode . $manager->mobile;
                })->toArray();
                
                // return $phoneNumbers;
                $otp = ''; // Generate a random 6-digit OTP
                $msgbody = "Customer appraisal request received."; 

                // Send OTP to managers
                $responses = sendOtpToMultiple($phoneNumbers, $otp, $msgbody);

                session()->forget('otp');

                $generatedCustomerId = $request->session()->get('generatedCustomerId');

                $formattedTimestamp = Carbon::now()->format('l / d-m-Y / H:i:s A'); // Example: "Monday / 06/08/2024 / 12:34:56"

                $customer = Customer::where('customerId', $generatedCustomerId)->first();

                $customer->requestTimestampCust = $formattedTimestamp;
                $customer->save();

                foreach ($responses as $phone => $response) {
                    if (is_string($response) && strpos($response, 'SM') === 0) {
                        // At least one message sent successfully
                        return response()->json(['success' => true]);

                    }
                }


            // return response()->json(['success' => true]);

            } else {
                return response()->json(['success' =>false, 'error' =>'Please try again or check network connection.']);
            }
        } else {
            return response()->json(['success' =>'wrong OTP', 'error' => 'Invalid OTP.']);
        }
    }

    public function appraisalConfirmCutomer(Request $request)
    {
        return view('home.appraisalConfirmCust');
    }
    
    public function CustomerOfferAccepted(Request $request)
    {
        return view('home.customerOfferAccepted');
    }

    public function customerAcceptOffer($custID)
    {
        $customer = Customer::where('custurl', $custID)->first();
       
        if ($customer) {
            if (empty($customer->customerTextOpenedTimestamp)) {
              
                $customer->customerTextOpenedTimestamp = Carbon::now()->format('l / d-m-Y / H:i:s A');
                $customer->save();
            }
    
            return view('home.customerAcceptOffer', ['Customer' => $customer]);
        } else {
           
            abort(404);
        }
    }

    public function customerAcceptOfferAjax(Request $request)
    {
        $validatedData = $request->validate([
            'Custurl' => 'required', 
            'offerAmount' => 'required', 

        ]);

        $Custurl = $validatedData['Custurl'];

        $offerAmount = $validatedData['offerAmount'];

        $customer = Customer::where('custurl',$Custurl)->first();

        if (!$customer) {
            return response()->json(['success' => false, 'error' => 'Customer not found.'], 404);
        }


        $encryptedId = Crypt::encrypt($customer->customerid);
        $shortId = substr(md5($encryptedId), 0, 30);
        // Generate the URL for the named route
        $url = route('manager.accept.offer', ['managerurl' => $shortId]);
        $request->session()->put('managerCustURL', $url);
        // return response()->json(['success' => false, 'error' =>  $custID], 404);

        $managerMobile =$customer->employeeMobile;
        $otp = ''; 
        $msgbody = "Offer Accepted: CLICK HERE TO VIEW OFFER DETAILS: $url";

        $response = sendOtp($managerMobile, $otp, $msgbody);

        if (is_string($response) && strpos($response, 'SM') === 0) {

        $customer->offerAcceptedPrice = $offerAmount;
        $customer->offerAcceptedTimestampCust = Carbon::now()->format('l / d-m-Y / H:i:s A');
        $customer->offerAccepted = 'Yes';
        $customer->managerurl = $shortId;
        if ($customer->save()) {
            return response()->json(['success' => true, 'message' => 'Offer submitted by customer successfully.']);
        } else {
            return response()->json(['success' => false, 'error' => 'Failed to submit offer by customer.'], 500);
        }
    }else{
        return response()->json(['success' => false, 'error' => 'Failed to send  msg to Manager.'], 500);

        }
    }

    public function managerSubmitOffer()
    {
        return view('home.managerSubmitOffer');
    }
    
    public function vehicleImage()
    {
        return view('home.serviceNoFile.vehicleImage');
    }
 
    public function vehicleImageUpload(Request $request)
    {
        $customerId = $request->session()->get('generatedCustomerId');
        $customer = Customer::where('customerId', $customerId)->first();

        if ($customer) {
            $images = [
                'frontView' => 'image1',
                'driverView' => 'image2',
                'rearView' => 'image3',
                'passengerSide' => 'image4',
                'interiorDash' => 'image5',
                'interiorFront' => 'image6',
                'interiorRearSeats' => 'image7',
                'interiorTrunk' => 'image8'
            ];

            foreach ($images as $column => $inputName) {
                if ($request->hasFile($inputName)) {
                    $file = $request->file($inputName);

                    $filePath = 'public/carImages/' . $file->hashName();
                    $destinationPath = storage_path('app/' . $filePath);

                    // Compress and save the image
                    $compressedImage = compressImage($file->getPathName(), $destinationPath, 75);

                    if ($compressedImage) {
                        $customer->$column = basename($filePath); // Save only the base name
                    }
                }
            }

            $customer->mileage = $request->input('mileage');
            $customer->save();

            return redirect('/appraisalConfirmCustomer')->with('success', 'Thank you for accepting the offer. The manager has been notified of your acceptance.');
        } else {
            return redirect()->back()->withErrors(['error' => 'Something went wrong, try again']);
        }
    }
    
    public function customerVehicleImages($customerId) 
    {
        if ($customerId) {
            $data['customerVehicleImages'] = Customer::where('custurl', $customerId)->first();
            return view('home.customerVehicleImages', $data);
        } else {
            abort(404, 'No record found.');
        }
    }
}