<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Http;
use App\Models\State;
use App\Models\Customer; 
use Illuminate\Support\Facades\Session;
use App\Models\User; // Assuming you have a User model
use Illuminate\Support\Facades\View;
use Carbon\Carbon; // Make sure you have Carbon imported for date formatting
use Illuminate\Support\Facades\Crypt;


class ManagerLink extends Controller
{
    public function managerAuth(Request $request)
    {
        // $request->session()->forget('managerId');

        return view('home.managerAuth');
    }
    
    public function managerVerify(Request $request)
    {
        return view('home.managerAuthotp');
    }
   
    public function managerVerifyOTP(Request $request)
    {
        // Validate the request
        $request->validate([
            'mobile' => 'required|numeric',
          
        ]);
    
        // Combine country code and mobile number
        $mobile = $request->countryCode . $request->mobile;
    
        // Retrieve the manager by mobile number and role type
        $manager = User::where([
            'countryCode'=>$request->countryCode,
            'mobile' => $request->mobile,
            'roleType' => 'Manager',
            'isDeleted' => '1', 
        ])->first();
   
        if (!$manager) {
            return back()->with('error', 'Manager not found or is deleted')->withInput();

        }
               $dealer = User::where([
            'id' => $manager->dealerId, 
            'roleType' => 'Dealer',
            'status' => '1', 
            'isDeleted' => '1', 
        ])->first();
    
        if (!$dealer) {
            return back()->with('error', 'The dealer associated with this manager is either not active or is deleted.')->withInput();
        }
       
        if (!$manager->status) {
            return back()->with('error', 'Manager is not active.')->withInput();

        }
        $otp = rand(100000, 999999); 
        $msgbody= 'Dear Manager verify your mobile to continue, and your OTP is:  ';
        $response = sendOtp($mobile, $otp, $msgbody);
    
        if (is_string($response) && strpos($response, 'SM') === 0) {
            // $request->session()->put('managerOTP', $otp);
            $request->session()->put('managerOTP', '123456');

            $request->session()->put('managercountryCode', $request->countryCode);
            $request->session()->put('managermobile',$request->countryCode . $request->mobile);
            $request->session()->put('managerId',$manager->id);

            
            return redirect('/managerVerify')->with('success', 'Manager verification successful.');

        }else{
            return back()->with('error', 'Failed to send OTP: Please try again or enter your phone number with country code and check network connection.')->withInput();


        }
          
    }
  
    public function openAppraisal(Request $request)
    {
        $request->session()->forget('managerOTP');


        $manager = User::where([
            'id' => session()->get('managerId'),
        ])->first();

        $dealer = User::where([
            'id' =>  $manager->dealerId,
            'roleType' => 'Dealer',
            'status' => '1', 
            'isDeleted' => '1', 
        ])->first();
    // echo  $dealer->id;
    // die;


        $data['appraisalOpenList'] = Customer::whereNotNull('requestTimestampCust')
        ->where('requestTimestampCust', '!=', '')
        ->where('dealerId', ($dealer->id) ?? '')
        ->where(function($query) {
            $query->whereNull('managerId')
                  ->orWhere('managerId', '');
        })->get();

        $data['appraisalAcceptList'] = Customer::whereNotNull('requestTimestampCust')
        ->where('requestTimestampCust', '!=', '')
        ->where('managerId' , session()->get('managerId'))->get();

        return view('home.appraisalList', $data);
    }


    public function saveOpenAppraisal(Request $request)
{
    
    $CustomerId = $request->input('Customer');
    $managerid =$request->input('managerId');
    $customer = Customer::find($CustomerId);

    if (!$customer) {
        return response()->json(['success' => false, 'error' => 'Customer not found.'], 404);
    }

    if ($customer->managerId) {
        return response()->json(['exists' => true, 'error' => 'Request already accepted by another manager.'], 404); // 409 Conflict
    }

        $customer->managerId = $managerid;
    
        if ($customer->save()) {
            return response()->json(['success' => true, 'message' => 'managerID updated successfully.']);
        } else {
            return response()->json(['success' => false, 'error' => 'Failed to update managerID.'], 500);
        }
    }
    
// }

public function managerSubmitOffer(Request $request)
{
    session()->get('SenCustomerId');
    session()->get('SenMamagerId');
    $data['Customer'] = Customer::where(['id' =>session()->get('SenCustomerId')])->first(); 


    return view('home.managerSubmitOffer',$data);
}

public function managerSendAjax(Request $request)
{
    $CustomerId = $request->input('Customer');
    $managerId = $request->input('managerId');

    $request->session()->put('SenCustomerId', $CustomerId);
    $request->session()->put('SenMamagerId', $managerId);

    return response()->json(['success' => true]);
}

public function managerSubmitOfferAjax(Request $request)
{
    $validatedData = $request->validate([
        'Customer' => 'required', 
        'managerId' => 'required', 
        'offerAmount' => 'required', 
        'employeeMobile' => 'required', 
    ]);

    $CustomerId = $validatedData['Customer'];
    $managerId = $validatedData['managerId'];
    $offerAmount = $validatedData['offerAmount'];
    $employeeMobile = $validatedData['employeeMobile'] ?? null; // Default to null if not provided

    $customer = Customer::find($CustomerId);

    if (!$customer) {
        return response()->json(['success' => false, 'error' => 'Customer not found.'], 404);
    }

    
    // $custID = $customer->customerid; // Example customer ID
    // $fullEncrypted = encryptID($custID, ENCRYPTION_KEY);
    
    $encryptedId = Crypt::encrypt($customer->customerId);
    $shortId = substr(md5($encryptedId), 0, 30);
    // Generate the URL for the named route
    $url = route('customer.accept.offer', ['custId' => $shortId]);
    $customerVehicleImagesUrl = route('customerVehicleImages', ['customerId' => $shortId]);
    $request->session()->put('offerCustURL', $url);

    $custMobile = $customer->customerMobile;
    $otp = ''; 
    $msgbody = "Offer received for your car: CLICK HERE TO VIEW OFFER DETAILS: $url";

    $response = sendOtp($custMobile, $otp, $msgbody);

    if (is_string($response) && strpos($response, 'SM') === 0) {

    $customer->offerAmount = $offerAmount;
    $customer->offerSubmittedTimestamp = Carbon::now()->format('l / d-m-Y / H:i:s A');
    $customer->employeeMobile = $employeeMobile;
    $customer->custurl = $shortId;
    
    
    
    if ($customer->save()) {
        return response()->json(['success' => true, 'message' => 'Offer submitted by manager successfully.']);
    } else {
        return response()->json(['success' => false, 'error' => 'Failed to submit offer by manager.'], 500);
    }
}else{
    return response()->json(['success' => false, 'error' => 'Failed to send  msg to Customer.'], 500);

    }
}

public function managerAcceptOffer($managerurl)
{
    $customer = Customer::where('managerurl', $managerurl)->first();
   
    if ($customer) {
       
        return view('home.managerAcceptedOffer', ['Customer' => $customer]);
    } else {
       
        abort(404);
    }
}
}
