<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use App\Models\User;
use App\Models\State;
use App\Models\Country;
use Illuminate\Support\Facades\Storage;
use Symfony\Component\HttpFoundation\StreamedResponse;
// use Barryvdh\DomPDF\Facade as PDF;
use PDF;
use Mpdf\Mpdf;
use Illuminate\Support\Facades\View;
use Illuminate\Support\Facades\Hash;
use LaravelQRCode\Facades\QRCode as QRcodeimage;
use Illuminate\Support\Facades\Crypt;

class Users extends Controller
{
    public function index()
    {
        $data['Dealers'] = User::where(['roleType' => 'Dealer', 'isDeleted' => 1])
                           ->orderBy('id', 'DESC')
                           ->get();
        return view('admin.users.index', $data);
    }
    
    public function managers()
    {
        $data['Managers'] = User::where(['roleType' => 'Manager', 'isDeleted' => 1])
                           ->orderBy('dealerId', 'DESC')
                           ->get();
        return view('admin.manager.index', $data);
    }
    
    public function create()
    {
        $admin = User::where('roleType', 'Admin')->first();
        $data['adminRole'] = $admin ? $admin->roleType : '';
        $data['states'] = State::all();
        $data['countries'] = Country::all();
        return view('admin.users.create', $data);
    }
    
    public function managerCreate()
    {
        $admin = User::where('roleType', 'Admin')->first();
        $data = ['adminRole' => ( $admin ) ? $admin->roleType : ''];
        $data['Dealers'] = User::where(['roleType' => 'Dealer', 'isDeleted' => 1])
                                ->orderBy('id', 'DESC')
                                ->get();
         return view('admin.manager.create', $data);
    }

    public function showQRcode($dealerId)
    {
        $url = route('dealer.download', ['id' => $dealerId]);

        $qrCode = QrCode::size(300)->generate($url);

        return view('admin.users.qrcodepdf', ['qrCode' => $qrCode]);
    }

    public function downloadQRcodePDF($dealerId)
    {
        ini_set('memory_limit', '1024M'); 

        $url = route('dealer.download', ['dealerId' => $dealerId]);
        $qrCodeRaw = QrCode::size(200)->generate($url);
        $qrCode = preg_replace('/<\?xml[^>]+\?>/', '', $qrCodeRaw);

        $html = View::make('admin.users.qrcodepdf', compact('qrCode'))->render();

        $mpdf = new Mpdf();

        $mpdf->WriteHTML($html);

        $pdfContent = $mpdf->Output('', 'S');

        return response()->stream(
            function () use ($pdfContent) {
                echo $pdfContent;
            },
            200,
            [
                'Content-Type' => 'application/pdf',
                'Content-Disposition' => 'attachment; filename="qrcode_dealer_' . $dealerId . '.pdf"',
            ]
        );
    }
    
    public function downloadPDFold($dealerId)
    {
        $user = User::find($dealerId);
        
        if (!$user || !$user->qrcode) {
            return abort(404, 'File not found');
        }
        
        $filePath = 'public/assets/qrcodes/' .$user->qrcode;
        $fileName = "qrcode_dealer_$dealerId.pdf";
    
        // Download the file
        return Storage::download($filePath, $fileName);
    }

    public function downloadPDF($dealerId)
    {
        $user = User::find($dealerId);
        if (!$user || !$user->qrcode) {
            return abort(404, 'File not found');
        }
        $filePath = 'public/assets/qrcodes/' . $user->qrcode;

        if (!Storage::exists($filePath)) {
            return abort(404, 'File not found');
        }

        $mpdf = new Mpdf(['mode' => 'utf-8', 'format' => [80, 90]]);

        $html = "<html>
                <body>
                <img src='" . Storage::path($filePath) . "' alt='QR Code'>
                </body>
                </html>";

        $mpdf->WriteHTML($html);

        $pdfContent = $mpdf->Output('', 'S');
        return response()->stream(
            function () use ($pdfContent) {
                echo $pdfContent;
            },
            200,
            [
                'Content-Type' => 'application/pdf',
                'Content-Disposition' => 'attachment; filename="qrcode_dealer_' . $dealerId . '.pdf"',
            ]
        );
    }
    
    public function save(Request $request)
    {
        $validationRules = [
            'name' => 'required|string|max:255',
            'email' => 'required|email|unique:users,email',
            'countryCode' => 'required',
            'mobile' => 'required|numeric|unique:users,mobile',
            'profile' => 'nullable|image|mimes:jpeg,png,jpg|max:2048',
        ];
        
        if ($request->password) {
            $validationRules['password'] = 'required|string|min:8|max:12';
        }
        $request->validate($validationRules);

        $filePath = null;
        if ($request->hasFile('profile')) {
            $path = $request->file('profile')->store('public/assets/images');
            $filePath = basename($path); // Get the filename only
        }
    
        $user = User::create([
            'date' => date("Y-m-d"),
            'name' => $request->name,
            'email' => $request->email,
            'countryCode' => $request->countryCode,
            'mobile' => $request->mobile,
            'roleType' => 'Dealer',
            'profile' => $filePath,
            'street' => $request->street,
            'city' => $request->city,
            'state' => $request->state,
            'zip' => $request->zip,
            'country' => $request->country,
            'password' => bcrypt($request->password),
            'created' => date('d-m-Y h:i:s A'),
            'createdBy' => getUserName(Auth::id()) ?? '',
        ]);
    
        if ($user) {
            $encryptedId = Crypt::encrypt($user->id);
            $shortId = substr(md5($encryptedId), 0, 30);

            $url = url('/VehicleAppraisal?dealerId=') . $shortId . '&sourceType=qr';

            $qrCodePath = 'public/assets/qrcodes/qrcode_' .  $shortId  . '.png';
            QRCodeImage::text($url)->setOutfile(Storage::path($qrCodePath))->png();

            $qrcodepath = basename($qrCodePath);
        
            $user->update(['qrcode' => $qrcodepath, 'url' =>  $shortId ]);
        
            return redirect('/dealers')->with('success', 'Dealer registered successfully!');
        } else {
            return back()->with('fail', 'Something went wrong!')->withInput();
        }
    }

    public function saveManager(Request $request)
    {
        
        // Validate the incoming request data
        $request->validate([
            'name' => 'required|string|max:255',
            'email' => 'required|email|unique:users,email',
            'countryCode' => 'required',
            'mobile' => 'required|numeric|unique:users,mobile',
            'profile' => 'nullable|image|mimes:jpeg,png,jpg|max:2048',
            'dealerId' => 'required',
        ]);
    

        $filePath = null;
        if ($request->hasFile('profile')) {
            $path = $request->file('profile')->store('public/assets/images');  
            $filePath = basename($path); 

        }

        // Create a new user record
        $user = User::create([
            'date' => date("Y-m-d"),
            'name' => $request->name,
            'email' => $request->email,
            'countryCode' => $request->countryCode,
            'mobile' => $request->mobile,            
            'roleType' => 'Manager' ,
            'profile' => $filePath,
            'dealerId' => $request->dealerId,
            'password' => $request->password ?? '',
            'created' => date('d-m-Y h:i:s A'),
            'createdBy' =>  getUserName(Auth::id()) ?? '',
        ]);
    
        if ($user) {
            return redirect('/managers')->with('success', 'Manager registered successfully!');
        } else {
            return back()->with('fail', 'Something went wrong!')->withInput();
        }
    }

    public function status($userId)
    {
        $user = User::find($userId);
        if ($user) {
            $user->status = $user->status == 1 ? 0 : 1;
            $user->save();
                return redirect()->back()->with('success', ' status updated successfully.');
        } else {
            return redirect()->back()->with('error', 'User not found.');
        }
    }
    
    public function info($userId)
    {
        $user = User::find($userId);
        return view('admin.users.info', ['user' => $user]);
    }
    
    public function managerInfo($userId)
    {
        $user = User::find($userId);
        $dealer = User::find($user->dealerId);
        $dealerName = $dealer->name;
        return view('admin.manager.info',['user' => $user, 'dealerName' => $dealerName]);
    }
    
    public function edit($userId)
    {
        $user = User::find($userId);
    
        if ($user) {
            $data['user'] = $user;
            $data['states'] = State::all();
            $data['countries'] = Country::all();            
            return view('admin.users.edit', $data);
        } else {
            return redirect()->back()->with('error', 'User not found.');
        }
    }
    
    public function managerEdit($userId)
    {

        $Dealers = User::where(['roleType' => 'Dealer', 'isDeleted' => 1])
        ->orderBy('id', 'DESC')
        ->get();
        
        $user = User::find($userId);
    
        if ($user) {
            return view('admin.manager.edit', ['user' => $user, 'Dealers' => $Dealers]);
        } else {
            return redirect()->back()->with('error', 'User not found.');
        }
    }

    public function update(Request $request, $userId)
    {
        $request->validate([
            'name' => 'required|string|max:255',
            'email' => 'required|email|unique:users,email,' . $userId,
            'countryCode' => 'required',
            'mobile' => 'required|numeric|unique:users,mobile,' . $userId,
            'profile' => 'nullable|image|mimes:jpeg,png,jpg|max:2048',
        ]);
    
        $user = User::find($userId);
    
        if (!$user) {
            return back()->with('fail', 'User not found!');
        }
    
        $filePath = $user->profile; // Keep the existing profile path by default
        if ($request->hasFile('profile')) {
            $path = $request->file('profile')->store('public/assets/images');
            //$filePath = Storage::url($path);
            $filePath = basename($path); 

        }
  
        $user->update([
            'name' => $request->name,
            'email' => $request->email,
            'countryCode' => $request->countryCode,
            'mobile' => $request->mobile,
            'profile' => $filePath,
            'street' => $request->street,
            'city' => $request->city,
            'state' => $request->state,
            'zip' => $request->zip,
            'country' => $request->country,            
            'updated' => date('d-m-Y h:i:s A'),
            'updatedBy' => getUserName(Auth::id()) ?? '',
        ]);
    
        return redirect('/dealers')->with('success', 'Dealer updated successfully!');
    }
    
    public function managerUpdate(Request $request, $userId)
    {
        $request->validate([
            'name' => 'required|string|max:255',
            'email' => 'required|email|unique:users,email,' . $userId,
            'countryCode' => 'required',
            'mobile' => 'required|numeric|unique:users,mobile,' . $userId,
            'profile' => 'nullable|image|mimes:jpeg,png,jpg|max:2048',
            'dealerId' => 'required',
        ]);
    
        $user = User::find($userId);
    
        if (!$user) {
            return back()->with('fail', 'User not found!');
        }
    
        $filePath = $user->profile; // Keep the existing profile path by default
        if ($request->hasFile('profile')) {
            $path = $request->file('profile')->store('public/assets/images');
            $filePath = basename($path); 
        }
    
        $user->update([
            'name' => $request->name,
            'email' => $request->email,
            'countryCode' => $request->countryCode,
            'mobile' => $request->mobile,
            'profile' => $filePath,
            'dealerId' =>$request->dealerId,
            'updated' => date('d-m-Y h:i:s A'),
            'updatedBy' =>  getUserName(Auth::id()) ?? '',
             
        ]);
    
        return redirect('/managers')->with('success', 'Manager updated successfully!');
    }
    
    public function delete($userId)
    {
        $user = User::find($userId);
    
        if ($user) {
            $user->isDeleted = $user->isDeleted == 1 ? 0 : 1;
            
            $user->save();
                return redirect()->back()->with('success', $user->isDeleted == 1 ? ' marked as deleted.' : ' marked as deleted.');
        } else {
            return redirect()->back()->with('error', 'User not found.');
        }
    }
    
    public function profile()
    {
        return view('admin.users.profile');
    }    
    
    public function updateProfile(Request $request)
    {

        $request->validate([
            'name' => 'required|string|max:255',
            'email' => 'required|email|unique:users,email,' . Auth::id(),
            'countryCode' => 'required',
            'mobile' => 'required|numeric|unique:users,mobile,' . Auth::id(),
            'profile' => 'nullable|image|mimes:jpeg,png,jpg|max:2048',
        ]);

        $userId = Auth::id();

        $user = User::find($userId);

        if (!$user) {
            return back()->with('fail', 'User not found!');
        }

        $filePath = $user->profile; // Keep the existing profile path by default
        if ($request->hasFile('profile')) {
            // Store the new file
            $path = $request->file('profile')->store('public/assets/images');
            $filePath = basename($path); 
        }

        $user->update([
            'name' => $request->name,
            'email' => $request->email,
            'countryCode' => $request->countryCode,
            'mobile' => $request->mobile,
            'profile' => $filePath, // Update the profile path
        ]);

        return redirect('/dashboard')->with('success', 'Your Profile has been updated successfully!');
    }
    
    public function changePassword(Request $request)
    {
        $request->validate([
            'currentPassword' => 'required',
            'newPassword' => 'required|min:8|max:12', // confirmed requires confirmPassword field
        ]);

        $user = Auth::user();

        if (!Hash::check($request->currentPassword, $user->password)) {
            return back()->withErrors(['currentPassword' => 'Current password does not match our records.']);
        }

        if ($request->newPassword !== $request->confirmPassword) {
            return back()->withErrors(['confirmPassword' => 'New password and confirm password do not match.']);
        }
        $user->password = Hash::make($request->newPassword);
        $user->save();
        return redirect('/dashboard')->with('status', 'Password changed successfully!');
    }   
}