<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class Customer extends Model
{
    use HasFactory;
    protected $table = 'customers';
    protected $primaryKey = 'id';
    protected $fillable = [
        'date',
        'customerId',
        'sourceType',
        'serviceType',
        'licensePlate',
        'state',
        'vin',
        'year',
        'make',
        'model',
        'color',
        'serviceAdvisorName',
        'mileage',
        'customerMobile',
        'frontView',
        'driverView',
        'rearView',
        'passengerSide',
        'interiorDash',
        'interiorFront',
        'interiorRearSeats',
        'interiorTrunk',
        'custOTPstatus',
        'requestTimestampCust',
        'textOpenedTimestamp',
        'offerSubmittedTimestamp',
        'offerAmount',
        'employeeMobile',
        'customerTextOpenedTimestamp',
        'offerAccepted',
        'offerAcceptedTimestampCust',
        'offerAcceptedPrice',
        'dealerId',
        'managerId',
        'custurl',
        'managerurl',
        'AdvisorCheck'
    ];

    protected static function boot()
    {
        parent::boot();

        // Attach the event handler for creating event
        static::creating(function ($customer) {
            $customer->customerId = $customer->generateCustomerId();
        });
    }
        /**
     * Generate a unique customerId.
     *
     * @return string
     */
    protected function generateCustomerId()
    {
        // Fetch the last customerId
        $lastCustomer = static::orderBy('customerId', 'desc')->first();
        
        if (!$lastCustomer) {
            // If no customer found, start with D0000001
            $nextId = 1;
        } else {
            // Extract the number from the last customerId
            $lastId = intval(substr($lastCustomer->customerId, 1));
            $nextId = $lastId + 1;
        }

        // Format the nextId with leading zeros
        return 'D' . str_pad($nextId, 7, '0', STR_PAD_LEFT);
    }
}
