@extends('admin.master')

@section('title')
Create Manager
@endsection()

@section('content')
<!-- Content Header (Page header) -->
<section class="content-header">
    <div class="container-fluid">
        <div class="row">
            <div class="col-sm-6">
                <h5>Create Manager</h5>
            </div>
            <div class="col-sm-6">
                <ol class="breadcrumb float-sm-right">
                    <li class="breadcrumb-item"><a href="{{ url('dashboard'); }}">Home</a></li>
                    <li class="breadcrumb-item active">Create Manager</li>
                </ol>
            </div>
        </div>
    </div><!-- /.container-fluid -->
</section>

<section class="content">
    <div class="container-fluid">
        <div class="row">
            <div class="col-12">                   
                @if (session('success'))
                <div class="alert alert-success alert-dismissible fade show" role="alert" id="flash-message">
                    {{ session('success') }}
                </div>
                @endif  
                @if (session('fail'))
                <div class="alert alert-danger alert-dismissible fade show" role="alert" id="flash-message">
                    {{ session('fail') }}
                </div>
                @endif
            </div>
            <div class="col-12">
                <form action="{{ url('managers/save'); }}" enctype="multipart/form-data" method="POST" autocomplete="off">
                    @csrf
                    <div class="card card-outline card-primary">
                        <div class="card-header">
                            <div class="title">
                                <h3 class="card-title text-primary">Create</h3>
                            </div>
                            <a href="{{ url('managers'); }}" class="btn btn-xs btn-primary float-right" title="Back">
                                <i class="fa fa-angle-double-left"></i> Back
                            </a>
                        </div>
                        <!-- /.card-header -->
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-3 col-lg-3 col-sm-3 col-xs-3 col-xxl-3 col-xl-3">
                                    <label>Name <span class="text-danger">*</span></label>
                                    <input type="text" name="name" value="{{ old('name'); }}" id="name" class="form-control form-control-sm" placeholder="Name" required="" autocomplete="off" />
                                    <span class="text-danger">
                                        @error('name')
                                            {{$message}}
                                        @enderror
                                    </span>
                                </div>
                                <div class="col-md-3 col-lg-3 col-sm-3 col-xs-3 col-xxl-3 col-xl-3">
                                    <label>Email <span class="text-danger">*</span></label>
                                    <input type="email" name="email" value="{{ old('email'); }}" id="email" class="form-control form-control-sm" placeholder="Email" required="" autocomplete="off" />
                                    <span class="text-danger">
                                        @error('email')
                                            {{$message}}
                                        @enderror
                                    </span>
                                </div>
                                <div class="col-md-3 col-lg-3 col-sm-3 col-xs-3 col-xxl-3 col-xl-3">
                                    <label for="countryCode">Country Code <span class="text-danger">*</span></label>
                                    {!! countrySelect($selectedCountryCode='+1') !!}
                                    <span class="text-danger">
                                        @error('countryCode')
                                            {{$message}}
                                        @enderror
                                    </span>                                    
                                </div>
                                <div class="col-md-3 col-lg-3 col-sm-3 col-xs-3 col-xxl-3 col-xl-3">
                                    <label>Mobile <span class="text-danger">*</span></label>
                                    <input type="number" name="mobile" value="{{ old('mobile'); }}" id="number" class="form-control form-control-sm" placeholder="Mobile" required="" autocomplete="off" />
                                    <span class="text-danger">
                                        @error('mobile')
                                            {{$message}}
                                        @enderror
                                    </span>
                                </div>
                                <div class="col-md-3 col-lg-3 col-sm-3 col-xs-3 col-xxl-3 col-xl-3">
                                    <label>Profile Image</label>
                                    <input type="file" name="profile" id="profile" class="form-control form-control-sm" accept="image/*" title="profile Image" />
                                    <span class="text-danger">
                                        @error('profile')
                                            {{$message}}
                                        @enderror
                                    </span>
                                </div>
                                <div class="col-md-3 col-lg-3 col-sm-3 col-xs-3 col-xxl-3 col-xl-3">
                                    <label>Select Dealer <span class="text-danger">*</span></label>
                                    <select name="dealerId" id="dealerId" class="form-control form-control-sm" required="">
                                        @foreach($Dealers as $dealer)
                                        <option value="{{ $dealer->id }}" {{ old('dealerId') == $dealer->id ? 'selected' : ''}}>{{ $dealer->name }}</option>
                                        @endforeach                                        
                                    </select>
                                    <span class="text-danger">
                                        @error('dealerId')
                                            {{$message}}
                                        @enderror
                                    </span>
                                </div> 
                            </div>
                        </div>
                        <div class="card-footer">
                            <button type="submit" class="btn btn-primary btn-sm">
                                Save
                            </button>
                            <button type="reset" class="btn btn-danger btn-sm">
                                Reset
                            </button>
                        </div>
                        <!-- /.card-body -->
                    </div>
                    <!-- /.card -->
                </form>
            </div>
            <!-- /.col -->
        </div>
        <!-- /.row -->        
    </div><!-- /.container-fluid -->
</section>
@endsection()

@section('javaScript')
<script type="text/javascript">

</script>
@endsection()