@extends('admin.master')

@section('title')
Profile
@endsection()

@section('content')
<!-- Content Header (Page header) -->
<section class="content-header">
    <div class="container-fluid">
        <div class="row">
            <div class="col-sm-6">
                <h5>Profile</h5>
            </div>
            <div class="col-sm-6">
                <ol class="breadcrumb float-sm-right">
                    <li class="breadcrumb-item"><a href="{{ url('dashboard'); }}">Home</a></li>
                    <li class="breadcrumb-item active">Profile</li>
                </ol>
            </div>
        </div>
    </div><!-- /.container-fluid -->
</section>

<section class="content">
    <div class="container-fluid">
        <div class="row">
            <div class="col-md-3">
                <!-- Profile Image -->
                <div class="card card-primary card-outline">
                    <div class="card-body box-profile">
                        <div class="text-center">
                            <img class="profile-user-img img-fluid img-circle" src="{{  (Auth::check()) ?  asset(Auth::user()->profile) : asset('assets/images/avatar.png'); }}" alt="User-profile-picture" />
                        </div>
                        <h3 class="profile-username text-center">{{  (Auth::check()) ?  Auth::user()->name : '' }}</h3>
                        <p class="text-muted text-center">{{  (Auth::check()) ?  Auth::user()->roleType : '' }}</p>
                    </div>
                    <!-- /.card-body -->
                </div>
                <!-- /.card -->
            </div>
            <!-- /.col -->
            <div class="col-md-9">
                <div class="card card-danger card-outline">
                    <div class="card-header">
                        <div class="title">
                            <h3 class="card-title">Update Profile</h3>
                        </div>
                    </div><!-- /.card-header -->
                    <div class="card-body">
                        <form action="{{ url('user/updateProfile') }}" method="POST" enctype="multipart/form-data" class="form-horizontal">
                           
                            @csrf
                            <div class="form-group row">
                                <label for="name" class="col-sm-2 col-form-label">Name <span class="text-danger">*</span></label>
                                <div class="col-sm-10">
                                    <input type="text" name="name" value="{{ (Auth::check()) ? Auth::user()->name : '';}}" id="name" class="form-control form-control-sm" placeholder="Name" required="" />
                                    <span class="text-danger">
                                        @error('name')
                                            {{$message}}
                                        @enderror
                                    </span>
                                </div>
                            </div>
                            <div class="form-group row">
                                <label for="email" class="col-sm-2 col-form-label">Email</label>
                                <div class="col-sm-10">
                                    <input type="text" name="email" value="{{ (Auth::check()) ? Auth::user()->email : '';}}" id="email" class="form-control form-control-sm" placeholder="Email" />
                                    <span class="text-danger">
                                        @error('email')
                                            {{$message}}
                                        @enderror
                                    </span>
                                </div>
                            </div>
                            <div class="form-group row">
                                <label for="mobile" class="col-sm-2 col-form-label">Mobile <span class="text-danger">*</span></label>
                                <div class="col-sm-10">
                                    <input type="tel" name="mobile" value="{{ (Auth::check()) ? Auth::user()->mobile : '';}}" id="mobile" class="form-control form-control-sm" placeholder="Mobile" />
                                    <span class="text-danger">
                                        @error('mobile')
                                            {{$message}}
                                        @enderror
                                    </span>
                                </div>
                            </div>
                            <div class="form-group row">
                                <label for="profile" class="col-sm-2 col-form-label">Profile</label>
                                <div class="col-sm-10">
                                    <input type="file" name="profile" id="profile" class="form-control form-control-sm" value="{{ (Auth::check()) ? Auth::user()->profile : '';}}"/>
                                    <input type="hidden" name="oldProfile" value="{{ old('oldProfile'); }}" id="oldProfile" />
                                    <span class="text-danger">
                                        @error('profile')
                                            {{$message}}
                                        @enderror
                                    </span>
                                </div>
                            </div>
                            <div class="form-group row">
                                <div class="offset-sm-2 col-sm-10">
                                    <button type="submit" class="btn btn-danger">Save Changes</button>
                                </div>
                            </div>
                        </form>
                    </div><!-- /.card-body -->
                </div>
                <!-- /.card -->
                <div class="card card-secondary card-outline">
                    <div class="card-header">
                        <div class="title">
                            <h3 class="card-title">Change Password</h3>
                        </div>
                    </div><!-- /.card-header -->
                    <div class="card-body">
                        <form action="{{ url('user/changePassword'); }}" method="POST" class="form-horizontal">
                            @csrf

                            <div class="form-group row">
                                <label for="currentPassword" class="col-sm-3 col-form-label">Current Password <span class="text-danger">*</span></label>
                                <div class="col-sm-9">
                                    <input type="password" name="currentPassword" value="{{ old('currentPassword'); }}" id="currentPassword" class="form-control form-control-sm" placeholder="Current Password" required="" />
                                </div>
                            </div>
                            <div class="form-group row">
                                <label for="newPassword" class="col-sm-3 col-form-label">New Password <span class="text-danger">*</span></label>
                                <div class="col-sm-9">
                                    <input type="password" name="newPassword" value="{{ old('newPassword'); }}" id="newPassword" class="form-control form-control-sm" placeholder="New Password" />
                                </div>
                            </div>
                            <div class="form-group row">
                                <label for="confirmPassword" class="col-sm-3 col-form-label">Confirm Password <span class="text-danger">*</span></label>
                                <div class="col-sm-9">
                                    <input type="password" name="confirmPassword" value="{{ old('confirmPassword'); }}" id="confirmPassword" class="form-control form-control-sm" placeholder="Confirm Password" />
                                </div>
                            </div>
                            <div class="form-group row">
                                <div class="offset-sm-2 col-sm-10">
                                    <button type="submit" class="btn btn-secondary">Save Changes</button>
                                </div>
                            </div>
                        </form>
                    </div><!-- /.card-body -->
                </div>
                <!-- /.card -->
            </div>
            <!-- /.col -->
        </div>
        <!-- /.row -->
    </div><!-- /.container-fluid -->
</section>
@endsection()