@extends('admin.master')

@section('title')
Customers Report
@endsection()

@section('content')
<!-- Content Header (Page header) -->
<section class="content-header">
    <div class="container-fluid">
        <div class="row">
            <div class="col-sm-6">
                <h5>Customers Report</h5>
            </div>
            <div class="col-sm-6">
                <ol class="breadcrumb float-sm-right">
                    <li class="breadcrumb-item"><a href="{{ url('dashboard'); }}">Home</a></li>
                    <li class="breadcrumb-item">Reports</li>
                    <li class="breadcrumb-item active">Customers</li>
                </ol>
            </div>
        </div>
    </div><!-- /.container-fluid -->
</section>

<section class="content">
    <div class="container-fluid">
        <div class="row">
            <div class="col-12">              
                @if (session('success'))
                <div class="alert alert-success alert-dismissible fade show" role="alert" id="flash-message">
                    {{ session('success') }}
                </div>
                @endif
                @if (session('error'))
                <div class="alert alert-danger alert-dismissible fade show" role="alert" id="flash-message">
                    {{ session('error') }}
                </div>
                @endif
            </div>
            
            <div class="col-12">
                <div class="card card-outline card-maroon">
                    <div class="card-header">
                        <div class="title">
                            <h3 class="card-title text-maroon">Customers</h3>
                        </div>
                    </div>
                    <!-- /.card-header -->
                    <div class="card-body">
                        <form action="" method="GET">
                            <div class="row">
                                <div class="col-2 form-group">
                                    <label for="from">From</label>
                                    <input type="date" name="from" value="{{ request('from') ? request('from') : date('Y-m-d'); }}" id="from" class="form-control form-control-sm" title="From" />
                                </div>
                                <div class="col-2 form-group">
                                    <label for="to">To</label>
                                    <input type="date" name="to" value="{{ request('to') ? request('to') : date('Y-m-d'); }}" id="to" class="form-control form-control-sm" title="To" />
                                </div>
                                <div class="col-2 form-group">
                                    <label for="dealerId">Dealers</label>
                                    <select name="dealerId" id="dealerId" class="form-control form-control-sm" title="Dealers">
                                        <option value="All" {{ request('dealerId') == 'All' ? 'selected' : ''; }}>All</option>
                                        @foreach ($dealers as $dealer)
                                        <option value="{{ $dealer->url; }}" {{ request('dealerId') == $dealer->url ? 'selected' : ''; }}>{{ $dealer->name; }}</option>
                                        @endForeach
                                    </select>
                                </div>
                                <div class="col-2 form-group">
                                    <label for="managerId">Managers</label>
                                    <select name="managerId" id="managerId" class="form-control form-control-sm" title="Managers">
                                        <option value="All" {{ request('managerId') == 'All' ? 'selected' : ''; }}>All</option>
                                        @foreach ($managers as $manager)
                                        <option value="{{ $manager->id; }}" {{ request('managerId') == $manager->id ? 'selected' : ''; }}>{{ $manager->name; }}</option>
                                        @endForeach
                                    </select>
                                </div>
                                <div class="col-2">
                                    <div class="form-group" style="margin-top: 31px;">
                                        <button type="submit" class="btn btn-sm bg-maroon">
                                            <i class="fa fa-search"></i>
                                        </button>
                                        <a href="{{ url('/reports/customers'); }}" class="btn btn-danger btn-sm" title="Refresh">
                                            <i class="fa fa-times"></i>
                                        </a>
                                    </div>
                                </div>
                            </div>
                        </form>
                        <div class="table-responsive">
                            <table class="table table-bordered">
                                <thead class="bg-maroon">
                                    <tr>
                                        <th>Sr</th>
                                        <th>Date</th>
                                        <th>Customer Id</th>
                                        <th>Mobile</th>
                                        <th>License Plate</th>
                                        <th>State</th>
                                        <th>Model</th>
                                        <th>Amount</th>
                                        <th></th>
                                    </tr>
                                </thead>
                                <tbody>
                                    @php
                                        $totalOfferAmount = 0;
                                    @endphp
                                    @foreach ($customers as $customer)
                                        @php
                                            $totalOfferAmount +=  (int)  $customer->offerAmount;
                                            $totalOfferPrice +=  (int)  $customer->offerAcceptedPrice;
                                        @endphp
                                    <tr>
                                        <td>{{ $loop->iteration; }}</td>
                                        <td>{{ date('d-m-Y', strtotime($customer->date)); }}</td>
                                        <td>{{ $customer->customerId; }}</td>
                                        <td>{{ $customer->customerMobile; }}</td>
                                        <td>{{ $customer->licensePlate; }}</td>
                                        <td>{{ $customer->state; }}</td>
                                        <td>{{ $customer->model; }}</td>                                        
                                        <td>&#36; {{ $customer->offerAmount; }}</td>
                                        <td>
                                            <a href="{{ url('/reports/serviceInfo/' . $customer->id); }}" class="btn btn-info btn-sm" title="Information">
                                                <i class="fa fa-info-circle"></i>
                                            </a>
                                        </td>
                                    </tr>
                                    @endForeach
                                </tbody>
                                <tfoot>
                                    <tr>
                                        <th colspan="7" style="text-align: right;">Total</th>
                                        <th><i class="fa fa-dollar-sign"></i> {{ $totalOfferAmount; }}</th>
                                        <th colspan="2"></th>
                                    </tr>
                                </tfoot>
                            </table>
                        </div>
                        <!-- /.table-responsive -->
                    </div>
                    <!-- /.card-body -->
                </div>
                <!-- /.card -->
            </div>
            <!-- /.col -->
        </div>
        <!-- /.row -->        
    </div><!-- /.container-fluid -->
</section>
@endsection()

@section('javaScript')
<script type="text/javascript">
    $(function () {
        $("table").DataTable({
            "responsive": true,
            "lengthChange": false,
            "autoWidth": false,
            "pageLength": 20,
            "lengthMenu": [[20, 50, 100, -1], [20, 50, 100, "All"]],
            "buttons": ["copy", "excel", "pdf", "print", "pageLength"]
        }).buttons().container().appendTo('#DataTables_Table_0_wrapper .col-md-6:eq(0)');
    });
</script>
@endsection()