@extends('admin.master')

@section('title')
Create User
@endsection()

@section('content')
<!-- Content Header (Page header) -->
<section class="content-header">
    <div class="container-fluid">
        <div class="row">
           
            <div class="col-sm-6">
                <h5>Create Dealer</h5>
            </div>
            <div class="col-sm-6">
                <ol class="breadcrumb float-sm-right">
                    <li class="breadcrumb-item"><a href="{{ url('dashboard'); }}">Home</a></li>
                    <li class="breadcrumb-item active">Create Dealer</li>
                </ol>
            </div>
        </div>
    </div><!-- /.container-fluid -->
</section>

<section class="content">
    <div class="container-fluid">
        <div class="row">
            <div class="col-12">
                @if (session('fail'))
                <div class="alert alert-danger alert-dismissible fade show" role="alert" id="flash-message">
                    {{ session('fail') }}
                </div>
                 @endif  
                 <form action="{{ url('user/save'); }}" enctype="multipart/form-data" method="POST" autocomplete="off">
                    @csrf
                    <div class="card card-outline card-primary">
                        <div class="card-header">
                            <div class="title">
                                <h3 class="card-title text-primary">Create</h3>
                            </div>
                            <a href="{{ url('dealers'); }}" class="btn btn-xs btn-primary float-right" title="Back">
                                <i class="fa fa-angle-double-left"></i> Back
                            </a>
                        </div>
                        <!-- /.card-header -->
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-3 col-lg-3 col-sm-3 col-xs-3 col-xxl-3 col-xl-3">
                                    <label>Name <span class="text-danger">*</span></label>
                                    <input type="text" name="name" value="{{ old('name'); }}" id="name" class="form-control form-control-sm" placeholder="Name" required="" autocomplete="off" />
                                    <span class="text-danger">
                                        @error('name')
                                            {{$message}}
                                        @enderror
                                    </span>
                                </div>
                                <div class="col-md-3 col-lg-3 col-sm-3 col-xs-3 col-xxl-3 col-xl-3">
                                    <label>Email <span class="text-danger">*</span></label>
                                    <input type="email" name="email" value="{{ old('email'); }}" id="email" class="form-control form-control-sm" placeholder="Email" required="" autocomplete="off" />
                                    <span class="text-danger">
                                        @error('email')
                                            {{$message}}
                                        @enderror
                                    </span>
                                </div>
                                <div class="col-md-3 col-lg-3 col-sm-3 col-xs-3 col-xxl-3 col-xl-3">
                                    <label for="countryCode">Country Code <span class="text-danger">*</span></label>
                                    {!! countrySelect($selectedCountryCode='+1') !!}
                                    <span class="text-danger">
                                        @error('countryCode')
                                            {{$message}}
                                        @enderror
                                    </span>                                    
                                </div>
                                <div class="col-md-3 col-lg-3 col-sm-3 col-xs-3 col-xxl-3 col-xl-3">
                                    <label>Mobile <span class="text-danger">*</span></label>
                                    <input type="number" name="mobile" value="{{ old('mobile'); }}" id="number" class="form-control form-control-sm" placeholder="Mobile" required="" autocomplete="off" />
                                    <span class="text-danger">
                                        @error('mobile')
                                            {{$message}}
                                        @enderror
                                    </span>
                                </div>
                                <div class="col-md-3 col-lg-3 col-sm-3 col-xs-3 col-xxl-3 col-xl-3">
                                    <label for="profile">Logo Image</label>
                                    <input type="file" name="profile" id="profile" class="form-control form-control-sm" accept="image/*" title="Logo Image" />
                                    <span class="text-danger">
                                        @error('profile')
                                            {{$message}}
                                        @enderror
                                    </span>
                                </div>
                                <div class="col-md-6 col-lg-6 col-sm-6 col-xs-6 col-xxl-6 col-xl-6">
                                    <label for="street">Street</label>
                                    <textarea name="street" id="street" class="form-control form-control-sm" placeholder="Street" autocomplete="off" rows="1">{{ old('street'); }}</textarea>
                                </div>
                                <div class="col-md-3 col-lg-3 col-sm-3 col-xs-3 col-xxl-3 col-xl-3">
                                    <label for="city">City</label>
                                    <input type="text" name="city" value="{{ old('city'); }}" id="city" class="form-control form-control-sm" placeholder="City" autocomplete="off" />
                                </div>
                                <div class="col-md-3 col-lg-3 col-sm-3 col-xs-3 col-xxl-3 col-xl-3">
                                    <label for="state">State</label>
                                    <select name="state" id="state" class="form-control form-control-sm" title="State">
                                        @foreach ($states as $state)
                                        <option value="{{ $state->id; }}" {{ old('state') == $state->id ? 'selected' : '' }}>{{ $state->name; }}</option>
                                        @endforeach
                                    </select>
                                </div>
                                <div class="col-md-3 col-lg-3 col-sm-3 col-xs-3 col-xxl-3 col-xl-3">
                                    <label for="zip">zip</label>
                                    <input type="number" name="zip" value="{{ old('zip'); }}" id="zip" class="form-control form-control-sm" placeholder="Zip" autocomplete="off" />
                                </div>
                                <div class="col-md-3 col-lg-3 col-sm-3 col-xs-3 col-xxl-3 col-xl-3">
                                    <label for="country">Country</label>
                                    <select name="country" id="country" class="form-control form-control-sm" title="Country">
                                        @foreach ($countries as $country)
                                        <option value="{{ $country->id; }}" {{ old('country') == $country->id || $country->id == '226' ? 'selected' : ''; }}>{{ $country->nicename; }}</option>
                                        @endforeach
                                    </select>
                                </div>
                            </div>
                            <div class="row">                                
                                <?php if($adminRole != 'Admin'){ ?>
                                <div class="col-md-3 col-lg-3 col-sm-3 col-xs-3 col-xxl-3 col-xl-3">
                                    <label for="">Password <span class="text-danger">*</span></label>
                                    <input type="password" name="password" value="{{ old('password'); }}" class="form-control form-control-sm" placeholder="Password" required="" />
                                    <span class="text-danger">
                                        @error('password')
                                            {{$message}}
                                        @enderror
                                    </span>
                                </div>
                                <?php } ?>
                            </div>
                        </div>
                        <div class="card-footer">
                            <button type="submit" class="btn btn-primary btn-sm">
                                Save
                            </button>
                            <button type="reset" class="btn btn-danger btn-sm">
                                Reset
                            </button>
                        </div>
                        <!-- /.card-body -->
                    </div>
                    <!-- /.card -->
                </form>
            </div>
            <!-- /.col -->
        </div>
        <!-- /.row -->        
    </div><!-- /.container-fluid -->
</section>
@endsection()

@section('javaScript')
<script type="text/javascript">

</script>
@endsection()