@extends('admin.master')

@section('title')
Dealer Report
@endsection()

@section('content')
<!-- Content Header (Page header) -->
<section class="content-header">
    <div class="container-fluid">
        <div class="row">
            <div class="col-sm-6">
                <h5>Dealer Report</h5>
            </div>
            <div class="col-sm-6">
                <ol class="breadcrumb float-sm-right">
                    <li class="breadcrumb-item"><a href="{{ url('dashboard'); }}">Home</a></li>
                    <li class="breadcrumb-item active">Dealer Report</li>
                </ol>
            </div>
        </div>
    </div><!-- /.container-fluid -->
</section>

<section class="content">
    <div class="container-fluid">
        <div class="row">
            <div class="col-12">              
                @if (session('success'))
                <div class="alert alert-success alert-dismissible fade show" role="alert" id="flash-message">
                    {{ session('success') }}
                </div>
                @endif
                @if (session('error'))
                <div class="alert alert-danger alert-dismissible fade show" role="alert" id="flash-message">
                    {{ session('error') }}
                </div>
                @endif
            </div>
            
            <div class="col-12">
                <div class="card card-outline card-purple">
                    <div class="card-header">
                        <div class="title">
                            <h3 class="card-title text-purple">Dealers</h3>
                        </div>
                        <a href="{{ url('dealer/create'); }}" class="btn btn-xs bg-purple float-right" title="Create">
                            <i class="fa fa-user-plus"></i> Create
                        </a>
                    </div>
                    <!-- /.card-header -->
                    <div class="card-body">
                        <div class="table-responsive">
                            <table class="table table-bordered">
                                <thead class="bg-purple">
                                    <tr>
                                        <th>Sr</th>
                                        <th>Name</th>
                                        <th>Email</th>
                                        <th>Mobile</th>
                                        <th>Status</th>
                                        <th></th>
                                    </tr>
                                </thead>
                                <tbody>
                                    @foreach ($Dealers as $dealer)
                                    <tr>
                                        <td>{{ $loop->iteration }}</td>
                                        <td>
                                            <div class="row">
                                                <div class="col-md-2 col-xs-2 col-lg-2 col-xxl-2 col-sm-2">
                                                    <img src="{{ $dealer->profile ? asset('/storage/assets/images/'. $dealer->profile) : asset('assets/images/avatar.png') }}" alt="avatar" style="width: 30px; border-radius: 25px;" />
                                                </div>
                                                <div class="col-md-8 col-xs-8 col-lg-8 col-xxl-8 col-sm-8 ml-1">
                                                    {{ $dealer->name }}
                                                </div>
                                            </div>                                            
                                        </td>
                                        <td>{{ $dealer->email }}</td>
                                        <td>{{ $dealer->countryCode . $dealer->mobile }}</td>
                                        <td>
                                            @if ($dealer->status == 1)
                                            <a href="{{ url('user/status/' . $dealer->id) }}" class="btn btn-xs bg-success" title="Change Status" onclick="return confirm('Are you sure you want to change the status?');">
                                                <i class="fa fa-thumbs-up"></i> Active
                                            </a>
                                            @else 
                                            <a href="{{ url('user/status/' . $dealer->id) }}" class="btn btn-xs bg-danger" title="Change Status" onclick="return confirm('Are you sure you want to change the status?');">
                                                <i class="fa fa-ban"></i> Inactive
                                            </a>                                            
                                            @endif
                                        </td>
                                        <td>
                                            <a href="{{ route('dealer.download', $dealer->id) }}" class="btn btn-warning btn-xs" title="Download QR Code PDF">
                                                <i class="fa fa-download"></i>
                                            </a>
                                            <a href="javascript:void(0);" class="btn btn-primary btn-xs" onclick="getUserInfo({{ $dealer->id }});" title="More Info">
                                                <i class="fa fa-info-circle"></i>
                                            </a>
                                            <a href="{{ url('dealer/edit/'.$dealer->id) }}" class="btn btn-success btn-xs" title="Edit">
                                                <i class="fa fa-edit"></i>
                                            </a>
                                            <a href="{{ url('user/delete/'.$dealer->id) }}" class="btn btn-danger btn-xs" title="Delete" onclick="return confirm('Are you sure you want to delete this record?');">
                                                <i class="fa fa-trash"></i>
                                            </a>
                                            
                                        </td>                                        
                                    </tr>
                                    @endForeach
                                </tbody>
                            </table>
                        </div>
                        <!-- /.table-responsive -->
                    </div>
                    <!-- /.card-body -->
                </div>
                <!-- /.card -->
            </div>
            <!-- /.col -->
        </div>
        <!-- /.row -->        
    </div><!-- /.container-fluid -->
</section>

<div class="modal fade" id="userInfo" tabindex="-1" role="dialog" aria-labelledby="userInfo" aria-hidden="true">
    <div class="modal-dialog modal-xl" role="document">
        <div class="modal-content"></div>
    </div>
</div>
@endsection()

@section('javaScript')
<script type="text/javascript">
    $(function () {
        $("table").DataTable({
            "responsive": true,
            "lengthChange": false,
            "autoWidth": false,
            "pageLength": 20,
            "lengthMenu": [[20, 50, 100, -1], [20, 50, 100, "All"]],
            "buttons": ["copy", "excel", "pdf", "print", "pageLength"]
        }).buttons().container().appendTo('#DataTables_Table_0_wrapper .col-md-6:eq(0)');
    });
    
    const getUserInfo = (userId) => {
        $("#userInfo .modal-dialog .modal-content").load("{{ url('user/info'); }}/" + userId);
        $('#userInfo').modal('show');        
    };

    function copyToClipboard(url) {
        navigator.clipboard.writeText(url).then(function() {
            alert("URL copied to clipboard: " + url);
        }).catch(function(err) {
            console.error('Failed to copy: ', err);
            alert("Failed to copy the URL. Please try again.");
        });
    }
</script>
@endsection()